/**
 * CFilterSelect - 筛选项目，单项选择
 * @author Tevin
 */

<template>
    <view
        class="c-filter-select"
        :class="'type-'+type"
    >
        <view
            class="label"
            v-if="type==='item'"
        >{{label}}</view>
        <picker
            mode="selector"
            range-key="name"
            :range="options2"
            :value="current"
            @change="evt=>handleChange(evt.detail.value)"
        >
            <view class="content">
                <view
                    class="label"
                    v-if="type==='bar'"
                >{{label}}:</view>
                <view :class="selected ? 'filled':'empty'">
                    {{selected ? options2[current].name : ('请选择' + label)}}
                </view>
                <view class="at-icon at-icon-chevron-down" />
            </view>
        </picker>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';

export default {
    name: 'CFilterSelect',
    props: {
        type: String,
        label: String,
        options: {
            type: Array,
            default: () => [],
        },
        cancelable: {
            type: Boolean,
            default: true,
        },
        value: null,
        onChange: Function,
    },
    data() {
        return {};
    },
    computed: {
        options2() {
            if (this.cancelable) {
                return [{ name: '- 取消选择 -' }, ...this.options];
            } else {
                return [...this.options];
            }
        },
        current() {
            for (let i = 0, item; (item = this.options2[i]); i++) {
                if (this.value === item.value) {
                    return i;
                }
            }
            return 0;
        },
        selected() {
            if (typeof this.value === 'undefined') {
                return false;
            }
            for (let item of this.options) {
                if (this.value === item.value) {
                    return true;
                }
            }
            return false;
        },
    },
    methods: {
        handleChange(index) {
            const selectIndex = Number(index);
            if (this.cancelable) {
                if (selectIndex > 0) {
                    this.onChange(this.options2[selectIndex].value);
                } else {
                    this.onChange();
                }
            } else {
                this.onChange(this.options2[selectIndex].value);
            }
        },
    },
};
</script>